from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import param_pb2 as _param_pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import tree_pb2 as _tree_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DurativeAction(_message.Message):
    __slots__ = ("header", "name", "parameters", "at_start_requirements", "over_all_requirements", "at_end_requirements", "at_start_effects", "at_end_effects")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    AT_START_REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    OVER_ALL_REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    AT_END_REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    AT_START_EFFECTS_FIELD_NUMBER: _ClassVar[int]
    AT_END_EFFECTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    parameters: _containers.RepeatedCompositeFieldContainer[_param_pb2.Param]
    at_start_requirements: _tree_pb2.Tree
    over_all_requirements: _tree_pb2.Tree
    at_end_requirements: _tree_pb2.Tree
    at_start_effects: _tree_pb2.Tree
    at_end_effects: _tree_pb2.Tree
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., parameters: _Optional[_Iterable[_Union[_param_pb2.Param, _Mapping]]] = ..., at_start_requirements: _Optional[_Union[_tree_pb2.Tree, _Mapping]] = ..., over_all_requirements: _Optional[_Union[_tree_pb2.Tree, _Mapping]] = ..., at_end_requirements: _Optional[_Union[_tree_pb2.Tree, _Mapping]] = ..., at_start_effects: _Optional[_Union[_tree_pb2.Tree, _Mapping]] = ..., at_end_effects: _Optional[_Union[_tree_pb2.Tree, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from make87_messages_ros2.rolling.tuw_geo_msgs.msg import geo_json_properties_pb2 as _geo_json_properties_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeoJSONGeometry(_message.Message):
    __slots__ = ("type", "coordinates", "properties")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    COORDINATES_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    type: str
    coordinates: _containers.RepeatedCompositeFieldContainer[_geo_point_pb2.GeoPoint]
    properties: _geo_json_properties_pb2.GeoJSONProperties
    def __init__(self, type: _Optional[str] = ..., coordinates: _Optional[_Iterable[_Union[_geo_point_pb2.GeoPoint, _Mapping]]] = ..., properties: _Optional[_Union[_geo_json_properties_pb2.GeoJSONProperties, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_control_msgs/msg/longitudinal.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/autoware_control_msgs/msg/longitudinal.proto\x12\x36make87_messages_ros2.rolling.autoware_control_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"\x99\x02\n\x0cLongitudinal\x12H\n\x05stamp\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12O\n\x0c\x63ontrol_time\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x10\n\x08velocity\x18\x03 \x01(\x02\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x02\x12\x0c\n\x04jerk\x18\x05 \x01(\x02\x12\x1f\n\x17is_defined_acceleration\x18\x06 \x01(\x08\x12\x17\n\x0fis_defined_jerk\x18\x07 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_control_msgs.msg.longitudinal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LONGITUDINAL']._serialized_start=198
  _globals['_LONGITUDINAL']._serialized_end=479
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.moveit_msgs.msg import constraints_pb2 as _constraints_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrajectoryConstraints(_message.Message):
    __slots__ = ("constraints",)
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    constraints: _containers.RepeatedCompositeFieldContainer[_constraints_pb2.Constraints]
    def __init__(self, constraints: _Optional[_Iterable[_Union[_constraints_pb2.Constraints, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.rolling.shape_msgs.msg import solid_primitive_pb2 as _solid_primitive_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RegionOfInterest3D(_message.Message):
    __slots__ = ("id", "pose", "primitive")
    ID_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    pose: _pose_stamped_pb2.PoseStamped
    primitive: _solid_primitive_pb2.SolidPrimitive
    def __init__(self, id: _Optional[str] = ..., pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., primitive: _Optional[_Union[_solid_primitive_pb2.SolidPrimitive, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import polygon_pb2 as _polygon_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Geozone(_message.Message):
    __slots__ = ("header", "id", "alert", "type", "data_type", "polygon", "z_up", "z_down")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ALERT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    Z_UP_FIELD_NUMBER: _ClassVar[int]
    Z_DOWN_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    alert: int
    type: str
    data_type: str
    polygon: _polygon_pb2.Polygon
    z_up: float
    z_down: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., alert: _Optional[int] = ..., type: _Optional[str] = ..., data_type: _Optional[str] = ..., polygon: _Optional[_Union[_polygon_pb2.Polygon, _Mapping]] = ..., z_up: _Optional[float] = ..., z_down: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/msg/video_record.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/ros_gz_interfaces/msg/video_record.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x94\x01\n\x0bVideoRecord\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\r\n\x05start\x18\x02 \x01(\x08\x12\x0c\n\x04stop\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x15\n\rsave_filename\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.msg.video_record_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIDEORECORD']._serialized_start=182
  _globals['_VIDEORECORD']._serialized_end=330
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_visualization_msgs/msg/textured_marker.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/jazzy/marti_visualization_msgs/msg/textured_marker.proto\x12\x37make87_messages_ros2.jazzy.marti_visualization_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a\x36make87_messages_ros2/jazzy/sensor_msgs/msg/image.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xef\x02\n\x0eTexturedMarker\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\x05\x12M\n\x08lifetime\x18\x05 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12@\n\x05image\x18\x06 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.sensor_msgs.msg.Image\x12@\n\x04pose\x18\x07 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x12\n\nresolution\x18\x08 \x01(\x01\x12\r\n\x05\x61lpha\x18\t \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_visualization_msgs.msg.textured_marker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TEXTUREDMARKER']._serialized_start=372
  _globals['_TEXTUREDMARKER']._serialized_end=739
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrackVisual(_message.Message):
    __slots__ = ("header", "ros2_header", "name", "id", "inherit_orientation", "min_dist", "max_dist", "is_static", "use_model_frame", "xyz", "inherit_yaw")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INHERIT_ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    MIN_DIST_FIELD_NUMBER: _ClassVar[int]
    MAX_DIST_FIELD_NUMBER: _ClassVar[int]
    IS_STATIC_FIELD_NUMBER: _ClassVar[int]
    USE_MODEL_FRAME_FIELD_NUMBER: _ClassVar[int]
    XYZ_FIELD_NUMBER: _ClassVar[int]
    INHERIT_YAW_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    name: str
    id: int
    inherit_orientation: bool
    min_dist: float
    max_dist: float
    is_static: bool
    use_model_frame: bool
    xyz: _vector3_pb2.Vector3
    inherit_yaw: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., name: _Optional[str] = ..., id: _Optional[int] = ..., inherit_orientation: bool = ..., min_dist: _Optional[float] = ..., max_dist: _Optional[float] = ..., is_static: bool = ..., use_model_frame: bool = ..., xyz: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., inherit_yaw: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_gnss.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import cfg_gnss_block_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_cfg__gnss__block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_gnss.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a>make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_gnss_block.proto\"\xad\x01\n\x07\x43\x66gGNSS\x12\x0f\n\x07msg_ver\x18\x01 \x01(\r\x12\x15\n\rnum_trk_ch_hw\x18\x02 \x01(\r\x12\x16\n\x0enum_trk_ch_use\x18\x03 \x01(\r\x12\x19\n\x11num_config_blocks\x18\x04 \x01(\r\x12G\n\x06\x62locks\x18\x05 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.ublox_msgs.msg.CfgGNSSBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_gnss_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGGNSS']._serialized_start=168
  _globals['_CFGGNSS']._serialized_end=341
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rtabmap_msgs.msg import map_data_pb2 as _map_data_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMap2Request(_message.Message):
    __slots__ = ("global_map", "optimized", "with_images", "with_scans", "with_user_data", "with_grids", "with_words", "with_global_descriptors")
    GLOBAL_MAP_FIELD_NUMBER: _ClassVar[int]
    OPTIMIZED_FIELD_NUMBER: _ClassVar[int]
    WITH_IMAGES_FIELD_NUMBER: _ClassVar[int]
    WITH_SCANS_FIELD_NUMBER: _ClassVar[int]
    WITH_USER_DATA_FIELD_NUMBER: _ClassVar[int]
    WITH_GRIDS_FIELD_NUMBER: _ClassVar[int]
    WITH_WORDS_FIELD_NUMBER: _ClassVar[int]
    WITH_GLOBAL_DESCRIPTORS_FIELD_NUMBER: _ClassVar[int]
    global_map: bool
    optimized: bool
    with_images: bool
    with_scans: bool
    with_user_data: bool
    with_grids: bool
    with_words: bool
    with_global_descriptors: bool
    def __init__(self, global_map: bool = ..., optimized: bool = ..., with_images: bool = ..., with_scans: bool = ..., with_user_data: bool = ..., with_grids: bool = ..., with_words: bool = ..., with_global_descriptors: bool = ...) -> None: ...

class GetMap2Response(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _map_data_pb2.MapData
    def __init__(self, data: _Optional[_Union[_map_data_pb2.MapData, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GeneralStatus(_message.Message):
    __slots__ = ("run_mode_active", "device_error", "application_error", "sleep_mode", "wait_for_input", "wait_for_cluster", "contamination_warning", "contamination_error", "dead_zone_detection", "temperature_warning")
    RUN_MODE_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ERROR_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    SLEEP_MODE_FIELD_NUMBER: _ClassVar[int]
    WAIT_FOR_INPUT_FIELD_NUMBER: _ClassVar[int]
    WAIT_FOR_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    DEAD_ZONE_DETECTION_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_WARNING_FIELD_NUMBER: _ClassVar[int]
    run_mode_active: int
    device_error: int
    application_error: int
    sleep_mode: int
    wait_for_input: int
    wait_for_cluster: int
    contamination_warning: int
    contamination_error: int
    dead_zone_detection: int
    temperature_warning: int
    def __init__(self, run_mode_active: _Optional[int] = ..., device_error: _Optional[int] = ..., application_error: _Optional[int] = ..., sleep_mode: _Optional[int] = ..., wait_for_input: _Optional[int] = ..., wait_for_cluster: _Optional[int] = ..., contamination_warning: _Optional[int] = ..., contamination_error: _Optional[int] = ..., dead_zone_detection: _Optional[int] = ..., temperature_warning: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nav_msgs/msg/map_meta_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/nav_msgs/msg/map_meta_data.proto\x12)make87_messages_ros2.rolling.nav_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"\xd8\x01\n\x0bMapMetaData\x12P\n\rmap_load_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x12\n\nresolution\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\x44\n\x06origin\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Poseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nav_msgs.msg.map_meta_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MAPMETADATA']._serialized_start=232
  _globals['_MAPMETADATA']._serialized_end=448
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg import confidence_pb2 as _confidence_pb2
from make87_messages_ros2.jazzy.vision_msgs.msg import bounding_box2_d_pb2 as _bounding_box2_d_pb2
from make87_messages_ros2.jazzy.vision_msgs.msg import point2_d_pb2 as _point2_d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MarkingEllipse(_message.Message):
    __slots__ = ("bb", "center", "confidence")
    BB_FIELD_NUMBER: _ClassVar[int]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    bb: _bounding_box2_d_pb2.BoundingBox2D
    center: _point2_d_pb2.Point2D
    confidence: _confidence_pb2.Confidence
    def __init__(self, bb: _Optional[_Union[_bounding_box2_d_pb2.BoundingBox2D, _Mapping]] = ..., center: _Optional[_Union[_point2_d_pb2.Point2D, _Mapping]] = ..., confidence: _Optional[_Union[_confidence_pb2.Confidence, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/composition_interfaces/srv/list_nodes.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/composition_interfaces/srv/list_nodes.proto\x12\x35make87_messages_ros2.jazzy.composition_interfaces.srv\"\x12\n\x10ListNodesRequest\"@\n\x11ListNodesResponse\x12\x17\n\x0f\x66ull_node_names\x18\x01 \x03(\t\x12\x12\n\nunique_ids\x18\x02 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.composition_interfaces.srv.list_nodes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LISTNODESREQUEST']._serialized_start=129
  _globals['_LISTNODESREQUEST']._serialized_end=147
  _globals['_LISTNODESRESPONSE']._serialized_start=149
  _globals['_LISTNODESRESPONSE']._serialized_end=213
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.lifecycle_msgs.msg import transition_description_pb2 as _transition_description_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetAvailableTransitionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetAvailableTransitionsResponse(_message.Message):
    __slots__ = ("available_transitions",)
    AVAILABLE_TRANSITIONS_FIELD_NUMBER: _ClassVar[int]
    available_transitions: _containers.RepeatedCompositeFieldContainer[_transition_description_pb2.TransitionDescription]
    def __init__(self, available_transitions: _Optional[_Iterable[_Union[_transition_description_pb2.TransitionDescription, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PauseRequest(_message.Message):
    __slots__ = ("header", "fleet_name", "robot_name", "mode_request_id", "type", "at_checkpoint")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    MODE_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    AT_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fleet_name: str
    robot_name: str
    mode_request_id: int
    type: int
    at_checkpoint: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fleet_name: _Optional[str] = ..., robot_name: _Optional[str] = ..., mode_request_id: _Optional[int] = ..., type: _Optional[int] = ..., at_checkpoint: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import application_data_pb2 as _application_data_pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import data_header_pb2 as _data_header_pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import derived_values_pb2 as _derived_values_pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import general_system_state_pb2 as _general_system_state_pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import intrusion_data_pb2 as _intrusion_data_pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import measurement_data_pb2 as _measurement_data_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RawMicroScanData(_message.Message):
    __slots__ = ("header", "derived_values", "general_system_state", "measurement_data", "intrusion_data", "application_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DERIVED_VALUES_FIELD_NUMBER: _ClassVar[int]
    GENERAL_SYSTEM_STATE_FIELD_NUMBER: _ClassVar[int]
    MEASUREMENT_DATA_FIELD_NUMBER: _ClassVar[int]
    INTRUSION_DATA_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _data_header_pb2.DataHeader
    derived_values: _derived_values_pb2.DerivedValues
    general_system_state: _general_system_state_pb2.GeneralSystemState
    measurement_data: _measurement_data_pb2.MeasurementData
    intrusion_data: _intrusion_data_pb2.IntrusionData
    application_data: _application_data_pb2.ApplicationData
    def __init__(self, header: _Optional[_Union[_data_header_pb2.DataHeader, _Mapping]] = ..., derived_values: _Optional[_Union[_derived_values_pb2.DerivedValues, _Mapping]] = ..., general_system_state: _Optional[_Union[_general_system_state_pb2.GeneralSystemState, _Mapping]] = ..., measurement_data: _Optional[_Union[_measurement_data_pb2.MeasurementData, _Mapping]] = ..., intrusion_data: _Optional[_Union[_intrusion_data_pb2.IntrusionData, _Mapping]] = ..., application_data: _Optional[_Union[_application_data_pb2.ApplicationData, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.rolling.nav_msgs.msg import path_pb2 as _path_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPlanRequest(_message.Message):
    __slots__ = ("start", "goal", "tolerance")
    START_FIELD_NUMBER: _ClassVar[int]
    GOAL_FIELD_NUMBER: _ClassVar[int]
    TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    start: _pose_stamped_pb2.PoseStamped
    goal: _pose_stamped_pb2.PoseStamped
    tolerance: float
    def __init__(self, start: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., goal: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., tolerance: _Optional[float] = ...) -> None: ...

class GetPlanResponse(_message.Message):
    __slots__ = ("plan",)
    PLAN_FIELD_NUMBER: _ClassVar[int]
    plan: _path_pb2.Path
    def __init__(self, plan: _Optional[_Union[_path_pb2.Path, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rc_reason_msgs/msg/grasp.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/rc_reason_msgs/msg/grasp.proto\x12-make87_messages_ros2.jazzy.rc_reason_msgs.msg\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\"\xbf\x01\n\x05Grasp\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x12\n\nmatch_uuid\x18\x03 \x01(\t\x12G\n\x04pose\x18\x04 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStamped\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x12\n\ngripper_id\x18\x06 \x01(\t\x12\x19\n\x11\x63ollision_checked\x18\x07 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rc_reason_msgs.msg.grasp_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRASP']._serialized_start=174
  _globals['_GRASP']._serialized_end=365
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ur_msgs.msg import analog_pb2 as _analog_pb2
from make87_messages_ros2.humble.ur_msgs.msg import digital_pb2 as _digital_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IOStates(_message.Message):
    __slots__ = ("header", "digital_in_states", "digital_out_states", "flag_states", "analog_in_states", "analog_out_states")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DIGITAL_IN_STATES_FIELD_NUMBER: _ClassVar[int]
    DIGITAL_OUT_STATES_FIELD_NUMBER: _ClassVar[int]
    FLAG_STATES_FIELD_NUMBER: _ClassVar[int]
    ANALOG_IN_STATES_FIELD_NUMBER: _ClassVar[int]
    ANALOG_OUT_STATES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    digital_in_states: _containers.RepeatedCompositeFieldContainer[_digital_pb2.Digital]
    digital_out_states: _containers.RepeatedCompositeFieldContainer[_digital_pb2.Digital]
    flag_states: _containers.RepeatedCompositeFieldContainer[_digital_pb2.Digital]
    analog_in_states: _containers.RepeatedCompositeFieldContainer[_analog_pb2.Analog]
    analog_out_states: _containers.RepeatedCompositeFieldContainer[_analog_pb2.Analog]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., digital_in_states: _Optional[_Iterable[_Union[_digital_pb2.Digital, _Mapping]]] = ..., digital_out_states: _Optional[_Iterable[_Union[_digital_pb2.Digital, _Mapping]]] = ..., flag_states: _Optional[_Iterable[_Union[_digital_pb2.Digital, _Mapping]]] = ..., analog_in_states: _Optional[_Iterable[_Union[_analog_pb2.Analog, _Mapping]]] = ..., analog_out_states: _Optional[_Iterable[_Union[_analog_pb2.Analog, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/detect_more_loop_closures.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/humble/rtabmap_msgs/srv/detect_more_loop_closures.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\"\xd8\x01\n\x1d\x44\x65tectMoreLoopClosuresRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x1a\n\x12\x63luster_radius_max\x18\x02 \x01(\x02\x12\x1a\n\x12\x63luster_radius_min\x18\x03 \x01(\x02\x12\x15\n\rcluster_angle\x18\x04 \x01(\x02\x12\x12\n\niterations\x18\x05 \x01(\x05\x12\x12\n\nintra_only\x18\x06 \x01(\x08\x12\x12\n\ninter_only\x18\x07 \x01(\x08\"`\n\x1e\x44\x65tectMoreLoopClosuresResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x64\x65tected\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.detect_more_loop_closures_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTMORELOOPCLOSURESREQUEST']._serialized_start=162
  _globals['_DETECTMORELOOPCLOSURESREQUEST']._serialized_end=378
  _globals['_DETECTMORELOOPCLOSURESRESPONSE']._serialized_start=380
  _globals['_DETECTMORELOOPCLOSURESRESPONSE']._serialized_end=476
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/global_position_target.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/mavros_msgs/msg/global_position_target.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf9\x02\n\x14GlobalPositionTarget\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x18\n\x10\x63oordinate_frame\x18\x02 \x01(\r\x12\x11\n\ttype_mask\x18\x03 \x01(\r\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x06 \x01(\x02\x12G\n\x08velocity\x18\x07 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12T\n\x15\x61\x63\x63\x65leration_or_force\x18\x08 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x0b\n\x03yaw\x18\t \x01(\x02\x12\x10\n\x08yaw_rate\x18\n \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.global_position_target_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GLOBALPOSITIONTARGET']._serialized_start=234
  _globals['_GLOBALPOSITIONTARGET']._serialized_end=611
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/geometry_msgs/msg/accel.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/geometry_msgs/msg/accel.proto\x12-make87_messages_ros2.humble.geometry_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\"\xc6\x01\n\x05\x41\x63\x63\x65l\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x46\n\x06linear\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12G\n\x07\x61ngular\x18\x03 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.geometry_msgs.msg.accel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ACCEL']._serialized_start=205
  _globals['_ACCEL']._serialized_end=403
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EcuInfo(_message.Message):
    __slots__ = ("header", "ros2_header", "name", "version", "mac_addr", "config_hash", "config_count_modified", "config_count_configured", "config_nvm_blank", "config_nvm_write_pending", "build_date", "license_date", "control_licensed", "log_filename", "log_filesystem_present", "log_fault")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MAC_ADDR_FIELD_NUMBER: _ClassVar[int]
    CONFIG_HASH_FIELD_NUMBER: _ClassVar[int]
    CONFIG_COUNT_MODIFIED_FIELD_NUMBER: _ClassVar[int]
    CONFIG_COUNT_CONFIGURED_FIELD_NUMBER: _ClassVar[int]
    CONFIG_NVM_BLANK_FIELD_NUMBER: _ClassVar[int]
    CONFIG_NVM_WRITE_PENDING_FIELD_NUMBER: _ClassVar[int]
    BUILD_DATE_FIELD_NUMBER: _ClassVar[int]
    LICENSE_DATE_FIELD_NUMBER: _ClassVar[int]
    CONTROL_LICENSED_FIELD_NUMBER: _ClassVar[int]
    LOG_FILENAME_FIELD_NUMBER: _ClassVar[int]
    LOG_FILESYSTEM_PRESENT_FIELD_NUMBER: _ClassVar[int]
    LOG_FAULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    name: str
    version: str
    mac_addr: str
    config_hash: str
    config_count_modified: int
    config_count_configured: int
    config_nvm_blank: bool
    config_nvm_write_pending: bool
    build_date: str
    license_date: str
    control_licensed: bool
    log_filename: str
    log_filesystem_present: bool
    log_fault: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., name: _Optional[str] = ..., version: _Optional[str] = ..., mac_addr: _Optional[str] = ..., config_hash: _Optional[str] = ..., config_count_modified: _Optional[int] = ..., config_count_configured: _Optional[int] = ..., config_nvm_blank: bool = ..., config_nvm_write_pending: bool = ..., build_date: _Optional[str] = ..., license_date: _Optional[str] = ..., control_licensed: bool = ..., log_filename: _Optional[str] = ..., log_filesystem_present: bool = ..., log_fault: bool = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import scan_point2202_pb2 as _scan_point2202_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScanData2202(_message.Message):
    __slots__ = ("header", "ibeo_header", "scan_number", "scanner_status", "sync_phase_offset", "scan_start_time", "scan_end_time", "angle_ticks_per_rotation", "start_angle_ticks", "end_angle_ticks", "scan_points_count", "mounting_yaw_angle_ticks", "mounting_pitch_angle_ticks", "mounting_roll_angle_ticks", "mounting_position_x", "mounting_position_y", "mounting_position_z", "ground_labeled", "dirt_labeled", "rain_labeled", "mirror_side", "scan_point_list")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    SCAN_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SCANNER_STATUS_FIELD_NUMBER: _ClassVar[int]
    SYNC_PHASE_OFFSET_FIELD_NUMBER: _ClassVar[int]
    SCAN_START_TIME_FIELD_NUMBER: _ClassVar[int]
    SCAN_END_TIME_FIELD_NUMBER: _ClassVar[int]
    ANGLE_TICKS_PER_ROTATION_FIELD_NUMBER: _ClassVar[int]
    START_ANGLE_TICKS_FIELD_NUMBER: _ClassVar[int]
    END_ANGLE_TICKS_FIELD_NUMBER: _ClassVar[int]
    SCAN_POINTS_COUNT_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_YAW_ANGLE_TICKS_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_PITCH_ANGLE_TICKS_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_ROLL_ANGLE_TICKS_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_POSITION_X_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_POSITION_Y_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_POSITION_Z_FIELD_NUMBER: _ClassVar[int]
    GROUND_LABELED_FIELD_NUMBER: _ClassVar[int]
    DIRT_LABELED_FIELD_NUMBER: _ClassVar[int]
    RAIN_LABELED_FIELD_NUMBER: _ClassVar[int]
    MIRROR_SIDE_FIELD_NUMBER: _ClassVar[int]
    SCAN_POINT_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    scan_number: int
    scanner_status: int
    sync_phase_offset: int
    scan_start_time: _time_pb2.Time
    scan_end_time: _time_pb2.Time
    angle_ticks_per_rotation: int
    start_angle_ticks: int
    end_angle_ticks: int
    scan_points_count: int
    mounting_yaw_angle_ticks: int
    mounting_pitch_angle_ticks: int
    mounting_roll_angle_ticks: int
    mounting_position_x: int
    mounting_position_y: int
    mounting_position_z: int
    ground_labeled: bool
    dirt_labeled: bool
    rain_labeled: bool
    mirror_side: int
    scan_point_list: _containers.RepeatedCompositeFieldContainer[_scan_point2202_pb2.ScanPoint2202]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., scan_number: _Optional[int] = ..., scanner_status: _Optional[int] = ..., sync_phase_offset: _Optional[int] = ..., scan_start_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., scan_end_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., angle_ticks_per_rotation: _Optional[int] = ..., start_angle_ticks: _Optional[int] = ..., end_angle_ticks: _Optional[int] = ..., scan_points_count: _Optional[int] = ..., mounting_yaw_angle_ticks: _Optional[int] = ..., mounting_pitch_angle_ticks: _Optional[int] = ..., mounting_roll_angle_ticks: _Optional[int] = ..., mounting_position_x: _Optional[int] = ..., mounting_position_y: _Optional[int] = ..., mounting_position_z: _Optional[int] = ..., ground_labeled: bool = ..., dirt_labeled: bool = ..., rain_labeled: bool = ..., mirror_side: _Optional[int] = ..., scan_point_list: _Optional[_Iterable[_Union[_scan_point2202_pb2.ScanPoint2202, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgMagStatus(_message.Message):
    __slots__ = ("header", "mag_x", "mag_y", "mag_z", "accel_x", "accel_y", "accel_z", "mags_in_range", "accels_in_range", "calibration")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAG_X_FIELD_NUMBER: _ClassVar[int]
    MAG_Y_FIELD_NUMBER: _ClassVar[int]
    MAG_Z_FIELD_NUMBER: _ClassVar[int]
    ACCEL_X_FIELD_NUMBER: _ClassVar[int]
    ACCEL_Y_FIELD_NUMBER: _ClassVar[int]
    ACCEL_Z_FIELD_NUMBER: _ClassVar[int]
    MAGS_IN_RANGE_FIELD_NUMBER: _ClassVar[int]
    ACCELS_IN_RANGE_FIELD_NUMBER: _ClassVar[int]
    CALIBRATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mag_x: bool
    mag_y: bool
    mag_z: bool
    accel_x: bool
    accel_y: bool
    accel_z: bool
    mags_in_range: bool
    accels_in_range: bool
    calibration: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mag_x: bool = ..., mag_y: bool = ..., mag_z: bool = ..., accel_x: bool = ..., accel_y: bool = ..., accel_z: bool = ..., mags_in_range: bool = ..., accels_in_range: bool = ..., calibration: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Sonar(_message.Message):
    __slots__ = ("left", "right")
    LEFT_FIELD_NUMBER: _ClassVar[int]
    RIGHT_FIELD_NUMBER: _ClassVar[int]
    left: float
    right: float
    def __init__(self, left: _Optional[float] = ..., right: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg import ball_pb2 as make87__messages__ros2_dot_jazzy_dot_soccer__vision__3d__msgs_dot_msg_dot_ball__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball_array.proto\x12\x34make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg\x1a?make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x97\x01\n\tBallArray\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12I\n\x05\x62\x61lls\x18\x02 \x03(\x0b\x32:.make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg.Ballb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg.ball_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BALLARRAY']._serialized_start=247
  _globals['_BALLARRAY']._serialized_end=398
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rc_reason_msgs/msg/item.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/rc_reason_msgs/msg/item.proto\x12-make87_messages_ros2.jazzy.rc_reason_msgs.msg\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\x1a=make87_messages_ros2/jazzy/rc_reason_msgs/msg/rectangle.proto\"\xcd\x01\n\x04Item\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x13\n\x0bgrasp_uuids\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12K\n\trectangle\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.rc_reason_msgs.msg.Rectangle\x12G\n\x04pose\x18\x05 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rc_reason_msgs.msg.item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ITEM']._serialized_start=236
  _globals['_ITEM']._serialized_end=441
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as _camera_info_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as _image_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RGBD(_message.Message):
    __slots__ = ("header", "ros2_header", "rgb_camera_info", "depth_camera_info", "rgb", "depth")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    RGB_CAMERA_INFO_FIELD_NUMBER: _ClassVar[int]
    DEPTH_CAMERA_INFO_FIELD_NUMBER: _ClassVar[int]
    RGB_FIELD_NUMBER: _ClassVar[int]
    DEPTH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    rgb_camera_info: _camera_info_pb2.CameraInfo
    depth_camera_info: _camera_info_pb2.CameraInfo
    rgb: _image_pb2.Image
    depth: _image_pb2.Image
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., rgb_camera_info: _Optional[_Union[_camera_info_pb2.CameraInfo, _Mapping]] = ..., depth_camera_info: _Optional[_Union[_camera_info_pb2.CameraInfo, _Mapping]] = ..., rgb: _Optional[_Union[_image_pb2.Image, _Mapping]] = ..., depth: _Optional[_Union[_image_pb2.Image, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/get_link_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.gazebo_msgs.msg import link_state_pb2 as make87__messages__ros2_dot_humble_dot_gazebo__msgs_dot_msg_dot_link__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/gazebo_msgs/srv/get_link_state.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/gazebo_msgs/msg/link_state.proto\"o\n\x13GetLinkStateRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tlink_name\x18\x02 \x01(\t\x12\x17\n\x0freference_frame\x18\x03 \x01(\t\"\xb9\x01\n\x14GetLinkStateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12J\n\nlink_state\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.humble.gazebo_msgs.msg.LinkState\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x16\n\x0estatus_message\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.get_link_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETLINKSTATEREQUEST']._serialized_start=210
  _globals['_GETLINKSTATEREQUEST']._serialized_end=321
  _globals['_GETLINKSTATERESPONSE']._serialized_start=324
  _globals['_GETLINKSTATERESPONSE']._serialized_end=509
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CommsPortInfo(_message.Message):
    __slots__ = ("port_id", "tx_pending", "tx_bytes", "tx_usage", "tx_peak_usage", "rx_pending", "rx_bytes", "rx_usage", "rx_peak_usage", "overrun_errs", "msgs", "skipped")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    TX_PENDING_FIELD_NUMBER: _ClassVar[int]
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    TX_USAGE_FIELD_NUMBER: _ClassVar[int]
    TX_PEAK_USAGE_FIELD_NUMBER: _ClassVar[int]
    RX_PENDING_FIELD_NUMBER: _ClassVar[int]
    RX_BYTES_FIELD_NUMBER: _ClassVar[int]
    RX_USAGE_FIELD_NUMBER: _ClassVar[int]
    RX_PEAK_USAGE_FIELD_NUMBER: _ClassVar[int]
    OVERRUN_ERRS_FIELD_NUMBER: _ClassVar[int]
    MSGS_FIELD_NUMBER: _ClassVar[int]
    SKIPPED_FIELD_NUMBER: _ClassVar[int]
    port_id: int
    tx_pending: int
    tx_bytes: int
    tx_usage: int
    tx_peak_usage: int
    rx_pending: int
    rx_bytes: int
    rx_usage: int
    rx_peak_usage: int
    overrun_errs: int
    msgs: _containers.RepeatedScalarFieldContainer[int]
    skipped: int
    def __init__(self, port_id: _Optional[int] = ..., tx_pending: _Optional[int] = ..., tx_bytes: _Optional[int] = ..., tx_usage: _Optional[int] = ..., tx_peak_usage: _Optional[int] = ..., rx_pending: _Optional[int] = ..., rx_bytes: _Optional[int] = ..., rx_usage: _Optional[int] = ..., rx_peak_usage: _Optional[int] = ..., overrun_errs: _Optional[int] = ..., msgs: _Optional[_Iterable[int]] = ..., skipped: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Battery(_message.Message):
    __slots__ = ("charge", "charging", "current", "temperature")
    CHARGE_FIELD_NUMBER: _ClassVar[int]
    CHARGING_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    charge: float
    charging: bool
    current: float
    temperature: float
    def __init__(self, charge: _Optional[float] = ..., charging: bool = ..., current: _Optional[float] = ..., temperature: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gpvtg(_message.Message):
    __slots__ = ("header", "message_id", "track_t", "track_t_ref", "track_m", "track_m_ref", "speed_n", "speed_n_unit", "speed_k", "speed_k_unit", "mode_indicator")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    TRACK_T_FIELD_NUMBER: _ClassVar[int]
    TRACK_T_REF_FIELD_NUMBER: _ClassVar[int]
    TRACK_M_FIELD_NUMBER: _ClassVar[int]
    TRACK_M_REF_FIELD_NUMBER: _ClassVar[int]
    SPEED_N_FIELD_NUMBER: _ClassVar[int]
    SPEED_N_UNIT_FIELD_NUMBER: _ClassVar[int]
    SPEED_K_FIELD_NUMBER: _ClassVar[int]
    SPEED_K_UNIT_FIELD_NUMBER: _ClassVar[int]
    MODE_INDICATOR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    message_id: str
    track_t: float
    track_t_ref: str
    track_m: float
    track_m_ref: str
    speed_n: float
    speed_n_unit: str
    speed_k: float
    speed_k_unit: str
    mode_indicator: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., track_t: _Optional[float] = ..., track_t_ref: _Optional[str] = ..., track_m: _Optional[float] = ..., track_m_ref: _Optional[str] = ..., speed_n: _Optional[float] = ..., speed_n_unit: _Optional[str] = ..., speed_k: _Optional[float] = ..., speed_k_unit: _Optional[str] = ..., mode_indicator: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Accelerometer(_message.Message):
    __slots__ = ("name", "x", "y", "z")
    NAME_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    name: str
    x: float
    y: float
    z: float
    def __init__(self, name: _Optional[str] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_task_msgs.msg import behavior_parameter_pb2 as _behavior_parameter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Behavior(_message.Message):
    __slots__ = ("name", "parameters")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    name: str
    parameters: _containers.RepeatedCompositeFieldContainer[_behavior_parameter_pb2.BehaviorParameter]
    def __init__(self, name: _Optional[str] = ..., parameters: _Optional[_Iterable[_Union[_behavior_parameter_pb2.BehaviorParameter, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Octomap(_message.Message):
    __slots__ = ("header", "binary", "id", "resolution", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BINARY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    binary: bool
    id: str
    resolution: float
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., binary: bool = ..., id: _Optional[str] = ..., resolution: _Optional[float] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/get_position_ik.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import position_ik_request_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_position__ik__request__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/moveit_msgs/srv/get_position_ik.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/move_it_error_codes.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/position_ik_request.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\"\x98\x01\n\x14GetPositionIKRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12R\n\nik_request\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.humble.moveit_msgs.msg.PositionIKRequest\"\xe3\x01\n\x15GetPositionIKResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12I\n\x08solution\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12Q\n\nerror_code\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.get_position_ik_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOSITIONIKREQUEST']._serialized_start=355
  _globals['_GETPOSITIONIKREQUEST']._serialized_end=507
  _globals['_GETPOSITIONIKRESPONSE']._serialized_start=510
  _globals['_GETPOSITIONIKRESPONSE']._serialized_end=737
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav2_msgs/srv/clear_entire_costmap.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import empty_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/nav2_msgs/srv/clear_entire_costmap.proto\x12)make87_messages_ros2.humble.nav2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x34make87_messages_ros2/humble/std_msgs/msg/empty.proto\"\x8b\x01\n\x19\x43learEntireCostmapRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12@\n\x07request\x18\x02 \x01(\x0b\x32/.make87_messages_ros2.humble.std_msgs.msg.Empty\"\x8d\x01\n\x1a\x43learEntireCostmapResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x08response\x18\x02 \x01(\x0b\x32/.make87_messages_ros2.humble.std_msgs.msg.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav2_msgs.srv.clear_entire_costmap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CLEARENTIRECOSTMAPREQUEST']._serialized_start=205
  _globals['_CLEARENTIRECOSTMAPREQUEST']._serialized_end=344
  _globals['_CLEARENTIRECOSTMAPRESPONSE']._serialized_start=347
  _globals['_CLEARENTIRECOSTMAPRESPONSE']._serialized_end=488
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Station(_message.Message):
    __slots__ = ("header", "task_id", "robot_type", "place_name")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROBOT_TYPE_FIELD_NUMBER: _ClassVar[int]
    PLACE_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    task_id: str
    robot_type: str
    place_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., task_id: _Optional[str] = ..., robot_type: _Optional[str] = ..., place_name: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Spherical(_message.Message):
    __slots__ = ("r", "phi", "theta")
    R_FIELD_NUMBER: _ClassVar[int]
    PHI_FIELD_NUMBER: _ClassVar[int]
    THETA_FIELD_NUMBER: _ClassVar[int]
    r: float
    phi: float
    theta: float
    def __init__(self, r: _Optional[float] = ..., phi: _Optional[float] = ..., theta: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg import basic_msg_pb2 as _basic_msg_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ComplexMsg(_message.Message):
    __slots__ = ("b",)
    B_FIELD_NUMBER: _ClassVar[int]
    b: _basic_msg_pb2.BasicMsg
    def __init__(self, b: _Optional[_Union[_basic_msg_pb2.BasicMsg, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_esr_msgs/msg/esr_status6.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/delphi_esr_msgs/msg/esr_status6.proto\x12.make87_messages_ros2.jazzy.delphi_esr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd3\x03\n\nEsrStatus6\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0e\n\x06\x63\x61nmsg\x18\x02 \x01(\t\x12\x17\n\x0fsupply_1p8v_a2d\x18\x03 \x01(\r\x12\x16\n\x0esupply_n5v_a2d\x18\x04 \x01(\r\x12\x15\n\rwave_diff_a2d\x18\x05 \x01(\r\x12\x1f\n\x17sw_version_dsp_3rd_byte\x18\x06 \x01(\r\x12\x1e\n\x16vertical_align_updated\x18\x07 \x01(\x08\x12\x19\n\x11system_power_mode\x18\x08 \x01(\r\x12\x14\n\x0c\x66ound_target\x18\t \x01(\x08\x12\x1c\n\x14recommend_unconverge\x18\n \x01(\x08\x12\x1e\n\x16\x66\x61\x63tory_align_status_1\x18\x0b \x01(\r\x12\x1e\n\x16\x66\x61\x63tory_align_status_2\x18\x0c \x01(\r\x12\x1c\n\x14\x66\x61\x63tory_misalignment\x18\r \x01(\x02\x12\x1f\n\x17serv_align_updates_done\x18\x0e \x01(\r\x12\x1d\n\x15vertical_misalignment\x18\x0f \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_esr_msgs.msg.esr_status6_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESRSTATUS6']._serialized_start=171
  _globals['_ESRSTATUS6']._serialized_end=638
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_psrdop2.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_message_header_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__message__header__pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_psrdop2_system_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__psrdop2__system__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_psrdop2.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\x1aNmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_message_header.proto\x1aNmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_psrdop2_system.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xca\x02\n\x0eNovatelPsrdop2\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x63\n\x12novatel_msg_header\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelMessageHeader\x12\x0c\n\x04gdop\x18\x03 \x01(\x02\x12\x0c\n\x04pdop\x18\x04 \x01(\x02\x12\x0c\n\x04hdop\x18\x05 \x01(\x02\x12\x0c\n\x04vdop\x18\x06 \x01(\x02\x12X\n\x07systems\x18\x07 \x03(\x0b\x32G.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelPsrdop2Systemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.novatel_psrdop2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NOVATELPSRDOP2']._serialized_start=343
  _globals['_NOVATELPSRDOP2']._serialized_end=673
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerConfigureRequest(_message.Message):
    __slots__ = ("sysid_primary", "compid_primary", "sysid_secondary", "compid_secondary", "gimbal_device_id")
    SYSID_PRIMARY_FIELD_NUMBER: _ClassVar[int]
    COMPID_PRIMARY_FIELD_NUMBER: _ClassVar[int]
    SYSID_SECONDARY_FIELD_NUMBER: _ClassVar[int]
    COMPID_SECONDARY_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    sysid_primary: int
    compid_primary: int
    sysid_secondary: int
    compid_secondary: int
    gimbal_device_id: int
    def __init__(self, sysid_primary: _Optional[int] = ..., compid_primary: _Optional[int] = ..., sysid_secondary: _Optional[int] = ..., compid_secondary: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ...) -> None: ...

class GimbalManagerConfigureResponse(_message.Message):
    __slots__ = ("success", "result")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    result: int
    def __init__(self, success: bool = ..., result: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class INSNavCart(_message.Message):
    __slots__ = ("header", "block_header", "gnss_mode", "error", "info", "gnss_age", "x", "y", "z", "accuracy", "latency", "datum", "sb_list", "x_std_dev", "y_std_dev", "z_std_dev", "xy_cov", "xz_cov", "yz_cov", "heading", "pitch", "roll", "heading_std_dev", "pitch_std_dev", "roll_std_dev", "heading_pitch_cov", "heading_roll_cov", "pitch_roll_cov", "vx", "vy", "vz", "vx_std_dev", "vy_std_dev", "vz_std_dev", "vx_vy_cov", "vx_vz_cov", "vy_vz_cov")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    GNSS_MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GNSS_AGE_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    ACCURACY_FIELD_NUMBER: _ClassVar[int]
    LATENCY_FIELD_NUMBER: _ClassVar[int]
    DATUM_FIELD_NUMBER: _ClassVar[int]
    SB_LIST_FIELD_NUMBER: _ClassVar[int]
    X_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    Y_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    Z_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    XY_COV_FIELD_NUMBER: _ClassVar[int]
    XZ_COV_FIELD_NUMBER: _ClassVar[int]
    YZ_COV_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    HEADING_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    PITCH_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    ROLL_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    HEADING_PITCH_COV_FIELD_NUMBER: _ClassVar[int]
    HEADING_ROLL_COV_FIELD_NUMBER: _ClassVar[int]
    PITCH_ROLL_COV_FIELD_NUMBER: _ClassVar[int]
    VX_FIELD_NUMBER: _ClassVar[int]
    VY_FIELD_NUMBER: _ClassVar[int]
    VZ_FIELD_NUMBER: _ClassVar[int]
    VX_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    VY_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    VZ_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    VX_VY_COV_FIELD_NUMBER: _ClassVar[int]
    VX_VZ_COV_FIELD_NUMBER: _ClassVar[int]
    VY_VZ_COV_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    gnss_mode: int
    error: int
    info: int
    gnss_age: int
    x: float
    y: float
    z: float
    accuracy: int
    latency: int
    datum: int
    sb_list: int
    x_std_dev: float
    y_std_dev: float
    z_std_dev: float
    xy_cov: float
    xz_cov: float
    yz_cov: float
    heading: float
    pitch: float
    roll: float
    heading_std_dev: float
    pitch_std_dev: float
    roll_std_dev: float
    heading_pitch_cov: float
    heading_roll_cov: float
    pitch_roll_cov: float
    vx: float
    vy: float
    vz: float
    vx_std_dev: float
    vy_std_dev: float
    vz_std_dev: float
    vx_vy_cov: float
    vx_vz_cov: float
    vy_vz_cov: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., gnss_mode: _Optional[int] = ..., error: _Optional[int] = ..., info: _Optional[int] = ..., gnss_age: _Optional[int] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ..., accuracy: _Optional[int] = ..., latency: _Optional[int] = ..., datum: _Optional[int] = ..., sb_list: _Optional[int] = ..., x_std_dev: _Optional[float] = ..., y_std_dev: _Optional[float] = ..., z_std_dev: _Optional[float] = ..., xy_cov: _Optional[float] = ..., xz_cov: _Optional[float] = ..., yz_cov: _Optional[float] = ..., heading: _Optional[float] = ..., pitch: _Optional[float] = ..., roll: _Optional[float] = ..., heading_std_dev: _Optional[float] = ..., pitch_std_dev: _Optional[float] = ..., roll_std_dev: _Optional[float] = ..., heading_pitch_cov: _Optional[float] = ..., heading_roll_cov: _Optional[float] = ..., pitch_roll_cov: _Optional[float] = ..., vx: _Optional[float] = ..., vy: _Optional[float] = ..., vz: _Optional[float] = ..., vx_std_dev: _Optional[float] = ..., vy_std_dev: _Optional[float] = ..., vz_std_dev: _Optional[float] = ..., vx_vy_cov: _Optional[float] = ..., vx_vz_cov: _Optional[float] = ..., vy_vz_cov: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import range_information_pb2 as _range_information_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Range(_message.Message):
    __slots__ = ("header", "ros2_header", "novatel_msg_header", "numb_of_observ", "info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    NUMB_OF_OBSERV_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    numb_of_observ: int
    info: _containers.RepeatedCompositeFieldContainer[_range_information_pb2.RangeInformation]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., numb_of_observ: _Optional[int] = ..., info: _Optional[_Iterable[_Union[_range_information_pb2.RangeInformation, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.qb_device_msgs.msg import info_pb2 as _info_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InitializeDeviceRequest(_message.Message):
    __slots__ = ("header", "id", "activate", "rescan", "max_repeats")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVATE_FIELD_NUMBER: _ClassVar[int]
    RESCAN_FIELD_NUMBER: _ClassVar[int]
    MAX_REPEATS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    activate: bool
    rescan: bool
    max_repeats: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., activate: bool = ..., rescan: bool = ..., max_repeats: _Optional[int] = ...) -> None: ...

class InitializeDeviceResponse(_message.Message):
    __slots__ = ("header", "success", "failures", "message", "info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    FAILURES_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    failures: int
    message: str
    info: _info_pb2.Info
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., failures: _Optional[int] = ..., message: _Optional[str] = ..., info: _Optional[_Union[_info_pb2.Info, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ("header", "ros2_header", "hardware_id", "firmware_version", "mcu_uptime", "connection_uptime", "pcb_temperature", "mcu_temperature")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_ID_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    MCU_UPTIME_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_UPTIME_FIELD_NUMBER: _ClassVar[int]
    PCB_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    MCU_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    hardware_id: str
    firmware_version: str
    mcu_uptime: _duration_pb2.Duration
    connection_uptime: _duration_pb2.Duration
    pcb_temperature: float
    mcu_temperature: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., hardware_id: _Optional[str] = ..., firmware_version: _Optional[str] = ..., mcu_uptime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., connection_uptime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., pcb_temperature: _Optional[float] = ..., mcu_temperature: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_triangle_pb2 as _mesh_triangle_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Mesh(_message.Message):
    __slots__ = ("header", "triangles", "vertices")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRIANGLES_FIELD_NUMBER: _ClassVar[int]
    VERTICES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    triangles: _containers.RepeatedCompositeFieldContainer[_mesh_triangle_pb2.MeshTriangle]
    vertices: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., triangles: _Optional[_Iterable[_Union[_mesh_triangle_pb2.MeshTriangle, _Mapping]]] = ..., vertices: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/srv/set_payload.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/ur_msgs/srv/set_payload.proto\x12(make87_messages_ros2.rolling.ur_msgs.srv\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\"u\n\x11SetPayloadRequest\x12\x0c\n\x04mass\x18\x01 \x01(\x02\x12R\n\x11\x63\x65nter_of_gravity\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\"%\n\x12SetPayloadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.srv.set_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPAYLOADREQUEST']._serialized_start=166
  _globals['_SETPAYLOADREQUEST']._serialized_end=283
  _globals['_SETPAYLOADRESPONSE']._serialized_start=285
  _globals['_SETPAYLOADRESPONSE']._serialized_end=322
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rmf_task_msgs.msg import task_description_pb2 as _task_description_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmitTaskRequest(_message.Message):
    __slots__ = ("requester", "description")
    REQUESTER_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    requester: str
    description: _task_description_pb2.TaskDescription
    def __init__(self, requester: _Optional[str] = ..., description: _Optional[_Union[_task_description_pb2.TaskDescription, _Mapping]] = ...) -> None: ...

class SubmitTaskResponse(_message.Message):
    __slots__ = ("success", "task_id", "message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    task_id: str
    message: str
    def __init__(self, success: bool = ..., task_id: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MonHW(_message.Message):
    __slots__ = ("header", "pin_sel", "pin_bank", "pin_dir", "pin_val", "noise_per_ms", "agc_cnt", "a_status", "a_power", "flags", "reserved0", "used_mask", "vp", "jam_ind", "reserved1", "pin_irq", "pull_h", "pull_l")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PIN_SEL_FIELD_NUMBER: _ClassVar[int]
    PIN_BANK_FIELD_NUMBER: _ClassVar[int]
    PIN_DIR_FIELD_NUMBER: _ClassVar[int]
    PIN_VAL_FIELD_NUMBER: _ClassVar[int]
    NOISE_PER_MS_FIELD_NUMBER: _ClassVar[int]
    AGC_CNT_FIELD_NUMBER: _ClassVar[int]
    A_STATUS_FIELD_NUMBER: _ClassVar[int]
    A_POWER_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    USED_MASK_FIELD_NUMBER: _ClassVar[int]
    VP_FIELD_NUMBER: _ClassVar[int]
    JAM_IND_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    PIN_IRQ_FIELD_NUMBER: _ClassVar[int]
    PULL_H_FIELD_NUMBER: _ClassVar[int]
    PULL_L_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pin_sel: int
    pin_bank: int
    pin_dir: int
    pin_val: int
    noise_per_ms: int
    agc_cnt: int
    a_status: int
    a_power: int
    flags: int
    reserved0: int
    used_mask: int
    vp: _containers.RepeatedScalarFieldContainer[int]
    jam_ind: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    pin_irq: int
    pull_h: int
    pull_l: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pin_sel: _Optional[int] = ..., pin_bank: _Optional[int] = ..., pin_dir: _Optional[int] = ..., pin_val: _Optional[int] = ..., noise_per_ms: _Optional[int] = ..., agc_cnt: _Optional[int] = ..., a_status: _Optional[int] = ..., a_power: _Optional[int] = ..., flags: _Optional[int] = ..., reserved0: _Optional[int] = ..., used_mask: _Optional[int] = ..., vp: _Optional[_Iterable[int]] = ..., jam_ind: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., pin_irq: _Optional[int] = ..., pull_h: _Optional[int] = ..., pull_l: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ContactInformation(_message.Message):
    __slots__ = ("header", "position", "normal", "depth", "contact_body_1", "body_type_1", "contact_body_2", "body_type_2")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    NORMAL_FIELD_NUMBER: _ClassVar[int]
    DEPTH_FIELD_NUMBER: _ClassVar[int]
    CONTACT_BODY_1_FIELD_NUMBER: _ClassVar[int]
    BODY_TYPE_1_FIELD_NUMBER: _ClassVar[int]
    CONTACT_BODY_2_FIELD_NUMBER: _ClassVar[int]
    BODY_TYPE_2_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    position: _point_pb2.Point
    normal: _vector3_pb2.Vector3
    depth: float
    contact_body_1: str
    body_type_1: int
    contact_body_2: str
    body_type_2: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., normal: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., depth: _Optional[float] = ..., contact_body_1: _Optional[str] = ..., body_type_1: _Optional[int] = ..., contact_body_2: _Optional[str] = ..., body_type_2: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class HistogramBucket(_message.Message):
    __slots__ = ("bucket_boundary", "count")
    BUCKET_BOUNDARY_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    bucket_boundary: float
    count: float
    def __init__(self, bucket_boundary: _Optional[float] = ..., count: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class OutcomeRequest(_message.Message):
    __slots__ = ("outcome", "target")
    OUTCOME_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    outcome: int
    target: str
    def __init__(self, outcome: _Optional[int] = ..., target: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CancelScheduleRequest(_message.Message):
    __slots__ = ("name", "finished")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FINISHED_FIELD_NUMBER: _ClassVar[int]
    name: str
    finished: bool
    def __init__(self, name: _Optional[str] = ..., finished: bool = ...) -> None: ...

class CancelScheduleResponse(_message.Message):
    __slots__ = ("success", "message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/destination_request.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import location_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_fleet_msgs/msg/destination_request.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1a>make87_messages_ros2/rolling/rmf_fleet_msgs/msg/location.proto\"\x9d\x01\n\x12\x44\x65stinationRequest\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x12\n\nrobot_name\x18\x02 \x01(\t\x12N\n\x0b\x64\x65stination\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Location\x12\x0f\n\x07task_id\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.destination_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DESTINATIONREQUEST']._serialized_start=191
  _globals['_DESTINATIONREQUEST']._serialized_end=348
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrTrack(_message.Message):
    __slots__ = ("header", "can_tx_detect_valid_level", "can_tx_detect_status", "can_tx_detect_range_rate", "can_tx_detect_range", "can_tx_detect_angle", "can_tx_detect_amplitude")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DETECT_VALID_LEVEL_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DETECT_STATUS_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DETECT_RANGE_RATE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DETECT_RANGE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DETECT_ANGLE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DETECT_AMPLITUDE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_tx_detect_valid_level: int
    can_tx_detect_status: bool
    can_tx_detect_range_rate: float
    can_tx_detect_range: float
    can_tx_detect_angle: float
    can_tx_detect_amplitude: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_tx_detect_valid_level: _Optional[int] = ..., can_tx_detect_status: bool = ..., can_tx_detect_range_rate: _Optional[float] = ..., can_tx_detect_range: _Optional[float] = ..., can_tx_detect_angle: _Optional[float] = ..., can_tx_detect_amplitude: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetNodesInRadiusRequest(_message.Message):
    __slots__ = ("header", "node_id", "x", "y", "z", "radius", "k")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    RADIUS_FIELD_NUMBER: _ClassVar[int]
    K_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    node_id: int
    x: float
    y: float
    z: float
    radius: float
    k: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., node_id: _Optional[int] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ..., radius: _Optional[float] = ..., k: _Optional[int] = ...) -> None: ...

class GetNodesInRadiusResponse(_message.Message):
    __slots__ = ("header", "ids", "poses", "dists_sqr")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    POSES_FIELD_NUMBER: _ClassVar[int]
    DISTS_SQR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ids: _containers.RepeatedScalarFieldContainer[int]
    poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    dists_sqr: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ids: _Optional[_Iterable[int]] = ..., poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., dists_sqr: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Obstacle(_message.Message):
    __slots__ = ("id", "pose", "polygon")
    ID_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    id: str
    pose: _pose_pb2.Pose
    polygon: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    def __init__(self, id: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., polygon: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import cartesian_point_pb2 as _cartesian_point_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CartesianTrajectoryPoint(_message.Message):
    __slots__ = ("point", "time_from_start")
    POINT_FIELD_NUMBER: _ClassVar[int]
    TIME_FROM_START_FIELD_NUMBER: _ClassVar[int]
    point: _cartesian_point_pb2.CartesianPoint
    time_from_start: _duration_pb2.Duration
    def __init__(self, point: _Optional[_Union[_cartesian_point_pb2.CartesianPoint, _Mapping]] = ..., time_from_start: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ActionExecution(_message.Message):
    __slots__ = ("type", "node_id", "action", "arguments", "success", "completion", "status")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    type: int
    node_id: str
    action: str
    arguments: _containers.RepeatedScalarFieldContainer[str]
    success: bool
    completion: float
    status: str
    def __init__(self, type: _Optional[int] = ..., node_id: _Optional[str] = ..., action: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ..., success: bool = ..., completion: _Optional[float] = ..., status: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GPSRAW(_message.Message):
    __slots__ = ("header", "fix_type", "lat", "lon", "alt", "eph", "epv", "vel", "cog", "satellites_visible", "alt_ellipsoid", "h_acc", "v_acc", "vel_acc", "hdg_acc", "yaw", "dgps_numch", "dgps_age")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FIX_TYPE_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    ALT_FIELD_NUMBER: _ClassVar[int]
    EPH_FIELD_NUMBER: _ClassVar[int]
    EPV_FIELD_NUMBER: _ClassVar[int]
    VEL_FIELD_NUMBER: _ClassVar[int]
    COG_FIELD_NUMBER: _ClassVar[int]
    SATELLITES_VISIBLE_FIELD_NUMBER: _ClassVar[int]
    ALT_ELLIPSOID_FIELD_NUMBER: _ClassVar[int]
    H_ACC_FIELD_NUMBER: _ClassVar[int]
    V_ACC_FIELD_NUMBER: _ClassVar[int]
    VEL_ACC_FIELD_NUMBER: _ClassVar[int]
    HDG_ACC_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    DGPS_NUMCH_FIELD_NUMBER: _ClassVar[int]
    DGPS_AGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fix_type: int
    lat: int
    lon: int
    alt: int
    eph: int
    epv: int
    vel: int
    cog: int
    satellites_visible: int
    alt_ellipsoid: int
    h_acc: int
    v_acc: int
    vel_acc: int
    hdg_acc: int
    yaw: int
    dgps_numch: int
    dgps_age: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fix_type: _Optional[int] = ..., lat: _Optional[int] = ..., lon: _Optional[int] = ..., alt: _Optional[int] = ..., eph: _Optional[int] = ..., epv: _Optional[int] = ..., vel: _Optional[int] = ..., cog: _Optional[int] = ..., satellites_visible: _Optional[int] = ..., alt_ellipsoid: _Optional[int] = ..., h_acc: _Optional[int] = ..., v_acc: _Optional[int] = ..., vel_acc: _Optional[int] = ..., hdg_acc: _Optional[int] = ..., yaw: _Optional[int] = ..., dgps_numch: _Optional[int] = ..., dgps_age: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UniversalJointVel(_message.Message):
    __slots__ = ("name", "ax1", "ax2")
    NAME_FIELD_NUMBER: _ClassVar[int]
    AX1_FIELD_NUMBER: _ClassVar[int]
    AX2_FIELD_NUMBER: _ClassVar[int]
    name: str
    ax1: float
    ax2: float
    def __init__(self, name: _Optional[str] = ..., ax1: _Optional[float] = ..., ax2: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ESCTelemetryItem(_message.Message):
    __slots__ = ("header", "temperature", "voltage", "current", "totalcurrent", "rpm", "count")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    TOTALCURRENT_FIELD_NUMBER: _ClassVar[int]
    RPM_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    temperature: float
    voltage: float
    current: float
    totalcurrent: float
    rpm: int
    count: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., temperature: _Optional[float] = ..., voltage: _Optional[float] = ..., current: _Optional[float] = ..., totalcurrent: _Optional[float] = ..., rpm: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.marine_acoustic_msgs.msg import detection_flag_pb2 as _detection_flag_pb2
from make87_messages_ros2.jazzy.marine_acoustic_msgs.msg import ping_info_pb2 as _ping_info_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SonarDetections(_message.Message):
    __slots__ = ("header", "ping_info", "flags", "two_way_travel_times", "tx_delays", "intensities", "tx_angles", "rx_angles")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PING_INFO_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    TWO_WAY_TRAVEL_TIMES_FIELD_NUMBER: _ClassVar[int]
    TX_DELAYS_FIELD_NUMBER: _ClassVar[int]
    INTENSITIES_FIELD_NUMBER: _ClassVar[int]
    TX_ANGLES_FIELD_NUMBER: _ClassVar[int]
    RX_ANGLES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ping_info: _ping_info_pb2.PingInfo
    flags: _containers.RepeatedCompositeFieldContainer[_detection_flag_pb2.DetectionFlag]
    two_way_travel_times: _containers.RepeatedScalarFieldContainer[float]
    tx_delays: _containers.RepeatedScalarFieldContainer[float]
    intensities: _containers.RepeatedScalarFieldContainer[float]
    tx_angles: _containers.RepeatedScalarFieldContainer[float]
    rx_angles: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ping_info: _Optional[_Union[_ping_info_pb2.PingInfo, _Mapping]] = ..., flags: _Optional[_Iterable[_Union[_detection_flag_pb2.DetectionFlag, _Mapping]]] = ..., two_way_travel_times: _Optional[_Iterable[float]] = ..., tx_delays: _Optional[_Iterable[float]] = ..., intensities: _Optional[_Iterable[float]] = ..., tx_angles: _Optional[_Iterable[float]] = ..., rx_angles: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CfgANT(_message.Message):
    __slots__ = ("header", "flags", "pins")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    PINS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    flags: int
    pins: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., flags: _Optional[int] = ..., pins: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/planning_options.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/moveit_msgs/msg/planning_options.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x41make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto\"\x91\x02\n\x0fPlanningOptions\x12X\n\x13planning_scene_diff\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningScene\x12\x11\n\tplan_only\x18\x02 \x01(\x08\x12\x13\n\x0blook_around\x18\x03 \x01(\x08\x12\x1c\n\x14look_around_attempts\x18\x04 \x01(\x05\x12\x1f\n\x17max_safe_execution_cost\x18\x05 \x01(\x01\x12\x0e\n\x06replan\x18\x06 \x01(\x08\x12\x17\n\x0freplan_attempts\x18\x07 \x01(\x05\x12\x14\n\x0creplan_delay\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.planning_options_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PLANNINGOPTIONS']._serialized_start=185
  _globals['_PLANNINGOPTIONS']._serialized_end=458
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeleteBasePlaneCalibrationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteBasePlaneCalibrationResponse(_message.Message):
    __slots__ = ("return_code",)
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavPOSLLH(_message.Message):
    __slots__ = ("i_tow", "lon", "lat", "height", "h_msl", "h_acc", "v_acc")
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    H_MSL_FIELD_NUMBER: _ClassVar[int]
    H_ACC_FIELD_NUMBER: _ClassVar[int]
    V_ACC_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    lon: int
    lat: int
    height: int
    h_msl: int
    h_acc: int
    v_acc: int
    def __init__(self, i_tow: _Optional[int] = ..., lon: _Optional[int] = ..., lat: _Optional[int] = ..., height: _Optional[int] = ..., h_msl: _Optional[int] = ..., h_acc: _Optional[int] = ..., v_acc: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as _move_it_error_codes_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_trajectory_pb2 as _robot_trajectory_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MotionSequenceResponse(_message.Message):
    __slots__ = ("error_code", "sequence_start", "planned_trajectories", "planning_time")
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_START_FIELD_NUMBER: _ClassVar[int]
    PLANNED_TRAJECTORIES_FIELD_NUMBER: _ClassVar[int]
    PLANNING_TIME_FIELD_NUMBER: _ClassVar[int]
    error_code: _move_it_error_codes_pb2.MoveItErrorCodes
    sequence_start: _robot_state_pb2.RobotState
    planned_trajectories: _containers.RepeatedCompositeFieldContainer[_robot_trajectory_pb2.RobotTrajectory]
    planning_time: float
    def __init__(self, error_code: _Optional[_Union[_move_it_error_codes_pb2.MoveItErrorCodes, _Mapping]] = ..., sequence_start: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ..., planned_trajectories: _Optional[_Iterable[_Union[_robot_trajectory_pb2.RobotTrajectory, _Mapping]]] = ..., planning_time: _Optional[float] = ...) -> None: ...
